==> server-api-3.5.1-sources.jar: com/xebialabs/deployit/core/api/dto/ConfigurationItemPropertyKind.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.core.api.dto;

import java.util.List;
import java.util.Set;

/**
 * Enumeration of possible configuration item types.
 */
public enum ConfigurationItemPropertyKind {
	/**
	 * A <tt>boolean</tt>.
	 */
	BOOLEAN,

	/**
	 * An <tt>int</tt>
	 */
	INTEGER,

	/**
	 * A {@link String}.
	 */
	STRING,

	/**
	 * An {@link Enum}.
	 */
	ENUM,

	/**
	 * A {@link List} of non-CI objects.
	 */
	LIST_OF_OBJECT,

	/**
	 * A {@link Set} of {@link String}s.
	 */
	SET_OF_STRING,

	/**
	 * A reference to a {@link ConfigurationItem}.
	 */
	CI,

	/**
	 * A {@link Set} of references to {@link ConfigurationItem}s.
	 */
	SET_OF_CI,

	/**
	 * A {@link Map} of {@link String} to {@link String}
	 */
	MAP_STRING_STRING,

	/**
	 * An unsupported property type.
	 */
	UNSUPPORTED;

}

==> server-api-3.6.4-sources.jar: com/xebialabs/deployit/core/api/dto/ConfigurationItemPropertyKind.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.core.api.dto;

import java.util.List;
import java.util.Set;

/**
 * Enumeration of possible configuration item types.
 */
public enum ConfigurationItemPropertyKind {
	/**
	 * A <tt>boolean</tt>.
	 */
	BOOLEAN,

	/**
	 * An <tt>int</tt>
	 */
	INTEGER,

	/**
	 * A {@link String}.
	 */
	STRING,

	/**
	 * An {@link Enum}.
	 */
	ENUM,

	/**
	 * A {@link List} of non-CI objects.
	 */
	LIST_OF_OBJECT,

	/**
	 * A {@link Set} of {@link String}s.
	 */
	SET_OF_STRING,

	/**
	 * A reference to a {@link ConfigurationItemDto}.
	 */
	CI,

	/**
	 * A {@link Set} of references to {@link ConfigurationItemDto}s.
	 */
	SET_OF_CI,

	/**
	 * A {@link Map} of {@link String} to {@link String}
	 */
	MAP_STRING_STRING,

	/**
	 * An unsupported property type.
	 */
	UNSUPPORTED;

}
